
Grizli Image Release v6.0 - 8 March 2023
========================================

.. image :: ceers-sm.field.jpg
  :width: 800
  :alt: CEERS 115+277+444
  
This release provides a repository of the primary public JWST imaging datasets,
now uniformly reprocessed with updated calibration files and ``grizli==1.8``.

JWST Imaging Data
~~~~~~~~~~~~~~~~~

* **S** "science" data, ``sci.fits``
* **W** inverse variance weights ``wht.fits``
* **RGB** Field image generated from F115W + F277W + F444W
* **ir** combined LW image for source detection
* Catalogs and photo-zs TBD

.. csv-table ::

    field,IMG,note,f070w,f090w,f115w,f150w,f182m,f200w,f210m,f277w,f300m,f356w,f410m,f430m,f444w,f460m,f480m,ir,NIS-f356w,NIS-f430m,NIS-f444w,NIS-f480m,NIS-f115w,NIS-f150w,NIS-f200w,_field
    ceers-full,`RGB <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/ceers-full-grizli-v6.0.field.jpg>`_ `f444w <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/ceers-full-grizli-v6.0.f444w.jpg>`_,ERS-1345, , ,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/ceers-full-grizli-v6.0-f115w-clear_drc_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/ceers-full-grizli-v6.0-f115w-clear_drc_wht.fits.gz>`_,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/ceers-full-grizli-v6.0-f150w-clear_drc_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/ceers-full-grizli-v6.0-f150w-clear_drc_wht.fits.gz>`_, ,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/ceers-full-grizli-v6.0-f200w-clear_drc_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/ceers-full-grizli-v6.0-f200w-clear_drc_wht.fits.gz>`_, ,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/ceers-full-grizli-v6.0-f277w-clear_drc_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/ceers-full-grizli-v6.0-f277w-clear_drc_wht.fits.gz>`_, ,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/ceers-full-grizli-v6.0-f356w-clear_drc_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/ceers-full-grizli-v6.0-f356w-clear_drc_wht.fits.gz>`_,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/ceers-full-grizli-v6.0-f410m-clear_drc_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/ceers-full-grizli-v6.0-f410m-clear_drc_wht.fits.gz>`_, ,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/ceers-full-grizli-v6.0-f444w-clear_drc_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/ceers-full-grizli-v6.0-f444w-clear_drc_wht.fits.gz>`_, , ,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/ceers-full-grizli-v6.0-ir_drc_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/ceers-full-grizli-v6.0-ir_drc_wht.fits.gz>`_, , , , , , , ,ceers-full
    cosweb,`RGB <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/cosweb-grizli-v6.0.field.jpg>`_ `f444w <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/cosweb-grizli-v6.0.f444w.jpg>`_,First epoch, , ,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/cosweb-grizli-v6.0-f115w-clear_drc_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/cosweb-grizli-v6.0-f115w-clear_drc_wht.fits.gz>`_,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/cosweb-grizli-v6.0-f150w-clear_drc_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/cosweb-grizli-v6.0-f150w-clear_drc_wht.fits.gz>`_, , , ,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/cosweb-grizli-v6.0-f277w-clear_drc_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/cosweb-grizli-v6.0-f277w-clear_drc_wht.fits.gz>`_, , , , ,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/cosweb-grizli-v6.0-f444w-clear_drc_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/cosweb-grizli-v6.0-f444w-clear_drc_wht.fits.gz>`_, , ,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/cosweb-grizli-v6.0-ir_drc_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/cosweb-grizli-v6.0-ir_drc_wht.fits.gz>`_, , , , , , , ,cosweb
    primer-cosmos,`RGB <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/primer-cosmos-grizli-v6.0.field.jpg>`_ `f444w <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/primer-cosmos-grizli-v6.0.f444w.jpg>`_,GO-1837, ,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/primer-cosmos-grizli-v6.0-f090w-clear_drc_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/primer-cosmos-grizli-v6.0-f090w-clear_drc_wht.fits.gz>`_,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/primer-cosmos-grizli-v6.0-f115w-clear_drc_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/primer-cosmos-grizli-v6.0-f115w-clear_drc_wht.fits.gz>`_,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/primer-cosmos-grizli-v6.0-f150w-clear_drc_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/primer-cosmos-grizli-v6.0-f150w-clear_drc_wht.fits.gz>`_, ,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/primer-cosmos-grizli-v6.0-f200w-clear_drc_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/primer-cosmos-grizli-v6.0-f200w-clear_drc_wht.fits.gz>`_, ,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/primer-cosmos-grizli-v6.0-f277w-clear_drc_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/primer-cosmos-grizli-v6.0-f277w-clear_drc_wht.fits.gz>`_, ,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/primer-cosmos-grizli-v6.0-f356w-clear_drc_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/primer-cosmos-grizli-v6.0-f356w-clear_drc_wht.fits.gz>`_,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/primer-cosmos-grizli-v6.0-f410m-clear_drc_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/primer-cosmos-grizli-v6.0-f410m-clear_drc_wht.fits.gz>`_, ,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/primer-cosmos-grizli-v6.0-f444w-clear_drc_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/primer-cosmos-grizli-v6.0-f444w-clear_drc_wht.fits.gz>`_, , , , , , , , , , ,primer-cosmos
    primer-uds,`RGB <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/primer-uds-grizli-v6.0.field.jpg>`_ `f444w <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/primer-uds-grizli-v6.0.f444w.jpg>`_,GO-1837, ,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/primer-uds-grizli-v6.0-f090w-clear_drc_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/primer-uds-grizli-v6.0-f090w-clear_drc_wht.fits.gz>`_,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/primer-uds-grizli-v6.0-f115w-clear_drc_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/primer-uds-grizli-v6.0-f115w-clear_drc_wht.fits.gz>`_,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/primer-uds-grizli-v6.0-f150w-clear_drc_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/primer-uds-grizli-v6.0-f150w-clear_drc_wht.fits.gz>`_, ,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/primer-uds-grizli-v6.0-f200w-clear_drc_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/primer-uds-grizli-v6.0-f200w-clear_drc_wht.fits.gz>`_, ,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/primer-uds-grizli-v6.0-f277w-clear_drc_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/primer-uds-grizli-v6.0-f277w-clear_drc_wht.fits.gz>`_, ,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/primer-uds-grizli-v6.0-f356w-clear_drc_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/primer-uds-grizli-v6.0-f356w-clear_drc_wht.fits.gz>`_,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/primer-uds-grizli-v6.0-f410m-clear_drc_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/primer-uds-grizli-v6.0-f410m-clear_drc_wht.fits.gz>`_, ,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/primer-uds-grizli-v6.0-f444w-clear_drc_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/primer-uds-grizli-v6.0-f444w-clear_drc_wht.fits.gz>`_, , , , , , , , , , ,primer-uds
    gdn,`RGB <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/gdn-grizli-v6.0.field.jpg>`_ `f444w <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/gdn-grizli-v6.0.f444w.jpg>`_,FRESCO, , , , ,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/gdn-grizli-v6.0-f182m-clear_drc_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/gdn-grizli-v6.0-f182m-clear_drc_wht.fits.gz>`_, ,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/gdn-grizli-v6.0-f210m-clear_drc_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/gdn-grizli-v6.0-f210m-clear_drc_wht.fits.gz>`_, , , , , ,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/gdn-grizli-v6.0-f444w-clear_drc_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/gdn-grizli-v6.0-f444w-clear_drc_wht.fits.gz>`_, , ,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/gdn-grizli-v6.0-ir_drc_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/gdn-grizli-v6.0-ir_drc_wht.fits.gz>`_, , , , , , , ,gdn
    gds,`RGB <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/gds-grizli-v6.0.field.jpg>`_ `f444w <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/gds-grizli-v6.0.f444w.jpg>`_,"FRESCO, GO-1963", , , , ,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/gds-grizli-v6.0-f182m-clear_drc_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/gds-grizli-v6.0-f182m-clear_drc_wht.fits.gz>`_, ,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/gds-grizli-v6.0-f210m-clear_drc_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/gds-grizli-v6.0-f210m-clear_drc_wht.fits.gz>`_, , , , ,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/gds-grizli-v6.0-f430m-clear_drc_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/gds-grizli-v6.0-f430m-clear_drc_wht.fits.gz>`_,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/gds-grizli-v6.0-f444w-clear_drc_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/gds-grizli-v6.0-f444w-clear_drc_wht.fits.gz>`_,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/gds-grizli-v6.0-f460m-clear_drc_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/gds-grizli-v6.0-f460m-clear_drc_wht.fits.gz>`_,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/gds-grizli-v6.0-f480m-clear_drc_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/gds-grizli-v6.0-f480m-clear_drc_wht.fits.gz>`_,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/gds-grizli-v6.0-ir_drc_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/gds-grizli-v6.0-ir_drc_wht.fits.gz>`_, ,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/gds-grizli-v6.0-clearp-f430m_drc_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/gds-grizli-v6.0-clearp-f430m_drc_wht.fits.gz>`_, ,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/gds-grizli-v6.0-clearp-f480m_drc_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/gds-grizli-v6.0-clearp-f480m_drc_wht.fits.gz>`_,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/gds-grizli-v6.0-f115wn-clear_drc_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/gds-grizli-v6.0-f115wn-clear_drc_wht.fits.gz>`_,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/gds-grizli-v6.0-f150wn-clear_drc_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/gds-grizli-v6.0-f150wn-clear_drc_wht.fits.gz>`_,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/gds-grizli-v6.0-f200wn-clear_drc_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/gds-grizli-v6.0-f200wn-clear_drc_wht.fits.gz>`_,gds
    ngdeep,`RGB <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/ngdeep-grizli-v6.0.field.jpg>`_ `f444w <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/ngdeep-grizli-v6.0.f444w.jpg>`_,GO-2079, , ,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/ngdeep-grizli-v6.0-f115w-clear_drc_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/ngdeep-grizli-v6.0-f115w-clear_drc_wht.fits.gz>`_,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/ngdeep-grizli-v6.0-f150w-clear_drc_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/ngdeep-grizli-v6.0-f150w-clear_drc_wht.fits.gz>`_, ,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/ngdeep-grizli-v6.0-f200w-clear_drc_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/ngdeep-grizli-v6.0-f200w-clear_drc_wht.fits.gz>`_, ,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/ngdeep-grizli-v6.0-f277w-clear_drc_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/ngdeep-grizli-v6.0-f277w-clear_drc_wht.fits.gz>`_, ,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/ngdeep-grizli-v6.0-f356w-clear_drc_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/ngdeep-grizli-v6.0-f356w-clear_drc_wht.fits.gz>`_, , ,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/ngdeep-grizli-v6.0-f444w-clear_drc_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/ngdeep-grizli-v6.0-f444w-clear_drc_wht.fits.gz>`_, , ,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/ngdeep-grizli-v6.0-ir_drc_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/ngdeep-grizli-v6.0-ir_drc_wht.fits.gz>`_, , , , , , , ,ngdeep
    j1235,`RGB <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/j1235-grizli-v6.0.field.jpg>`_ `f444w <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/j1235-grizli-v6.0.f444w.jpg>`_,COM-1063,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/j1235-grizli-v6.0-f070w-clear_drc_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/j1235-grizli-v6.0-f070w-clear_drc_wht.fits.gz>`_,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/j1235-grizli-v6.0-f090w-clear_drc_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/j1235-grizli-v6.0-f090w-clear_drc_wht.fits.gz>`_,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/j1235-grizli-v6.0-f115w-clear_drc_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/j1235-grizli-v6.0-f115w-clear_drc_wht.fits.gz>`_,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/j1235-grizli-v6.0-f150w-clear_drc_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/j1235-grizli-v6.0-f150w-clear_drc_wht.fits.gz>`_, ,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/j1235-grizli-v6.0-f200w-clear_drc_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/j1235-grizli-v6.0-f200w-clear_drc_wht.fits.gz>`_, ,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/j1235-grizli-v6.0-f277w-clear_drc_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/j1235-grizli-v6.0-f277w-clear_drc_wht.fits.gz>`_,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/j1235-grizli-v6.0-f300m-clear_drc_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/j1235-grizli-v6.0-f300m-clear_drc_wht.fits.gz>`_,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/j1235-grizli-v6.0-f356w-clear_drc_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/j1235-grizli-v6.0-f356w-clear_drc_wht.fits.gz>`_, , ,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/j1235-grizli-v6.0-f444w-clear_drc_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/j1235-grizli-v6.0-f444w-clear_drc_wht.fits.gz>`_, ,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/j1235-grizli-v6.0-f480m-clear_drc_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/j1235-grizli-v6.0-f480m-clear_drc_wht.fits.gz>`_,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/j1235-grizli-v6.0-ir_drc_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/j1235-grizli-v6.0-ir_drc_wht.fits.gz>`_, , , , , , , ,j1235
    jwst-nep-tdf-nrc,`RGB <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/jwst-nep-tdf-nrc-grizli-v6.0.field.jpg>`_ `f444w <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/jwst-nep-tdf-nrc-grizli-v6.0.f444w.jpg>`_,GTO-2738, ,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/jwst-nep-tdf-nrc-grizli-v6.0-f090w-clear_drc_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/jwst-nep-tdf-nrc-grizli-v6.0-f090w-clear_drc_wht.fits.gz>`_,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/jwst-nep-tdf-nrc-grizli-v6.0-f115w-clear_drc_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/jwst-nep-tdf-nrc-grizli-v6.0-f115w-clear_drc_wht.fits.gz>`_,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/jwst-nep-tdf-nrc-grizli-v6.0-f150w-clear_drc_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/jwst-nep-tdf-nrc-grizli-v6.0-f150w-clear_drc_wht.fits.gz>`_, ,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/jwst-nep-tdf-nrc-grizli-v6.0-f200w-clear_drc_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/jwst-nep-tdf-nrc-grizli-v6.0-f200w-clear_drc_wht.fits.gz>`_, ,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/jwst-nep-tdf-nrc-grizli-v6.0-f277w-clear_drc_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/jwst-nep-tdf-nrc-grizli-v6.0-f277w-clear_drc_wht.fits.gz>`_, ,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/jwst-nep-tdf-nrc-grizli-v6.0-f356w-clear_drc_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/jwst-nep-tdf-nrc-grizli-v6.0-f356w-clear_drc_wht.fits.gz>`_,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/jwst-nep-tdf-nrc-grizli-v6.0-f410m-clear_drc_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/jwst-nep-tdf-nrc-grizli-v6.0-f410m-clear_drc_wht.fits.gz>`_, ,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/jwst-nep-tdf-nrc-grizli-v6.0-f444w-clear_drc_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/jwst-nep-tdf-nrc-grizli-v6.0-f444w-clear_drc_wht.fits.gz>`_, , ,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/jwst-nep-tdf-nrc-grizli-v6.0-ir_drc_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/jwst-nep-tdf-nrc-grizli-v6.0-ir_drc_wht.fits.gz>`_, , , , , , , ,jwst-nep-tdf-nrc
    abell2744clu,`RGB <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/abell2744clu-grizli-v6.0.field.jpg>`_ `f444w <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/abell2744clu-grizli-v6.0.f444w.jpg>`_,"GLASS-ERS, UNCOVER, DD-2756", ,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/abell2744clu-grizli-v6.0-f090w-clear_drc_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/abell2744clu-grizli-v6.0-f090w-clear_drc_wht.fits.gz>`_,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/abell2744clu-grizli-v6.0-f115w-clear_drc_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/abell2744clu-grizli-v6.0-f115w-clear_drc_wht.fits.gz>`_,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/abell2744clu-grizli-v6.0-f150w-clear_drc_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/abell2744clu-grizli-v6.0-f150w-clear_drc_wht.fits.gz>`_, ,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/abell2744clu-grizli-v6.0-f200w-clear_drc_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/abell2744clu-grizli-v6.0-f200w-clear_drc_wht.fits.gz>`_, ,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/abell2744clu-grizli-v6.0-f277w-clear_drc_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/abell2744clu-grizli-v6.0-f277w-clear_drc_wht.fits.gz>`_, ,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/abell2744clu-grizli-v6.0-f356w-clear_drc_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/abell2744clu-grizli-v6.0-f356w-clear_drc_wht.fits.gz>`_,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/abell2744clu-grizli-v6.0-f410m-clear_drc_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/abell2744clu-grizli-v6.0-f410m-clear_drc_wht.fits.gz>`_, ,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/abell2744clu-grizli-v6.0-f444w-clear_drc_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/abell2744clu-grizli-v6.0-f444w-clear_drc_wht.fits.gz>`_, , ,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/abell2744clu-grizli-v6.0-ir_drc_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/abell2744clu-grizli-v6.0-ir_drc_wht.fits.gz>`_,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/abell2744clu-grizli-v6.0-clearp-f356w_drc_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/abell2744clu-grizli-v6.0-clearp-f356w_drc_wht.fits.gz>`_, ,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/abell2744clu-grizli-v6.0-clearp-f444w_drc_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/abell2744clu-grizli-v6.0-clearp-f444w_drc_wht.fits.gz>`_, ,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/abell2744clu-grizli-v6.0-f115wn-clear_drc_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/abell2744clu-grizli-v6.0-f115wn-clear_drc_wht.fits.gz>`_,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/abell2744clu-grizli-v6.0-f150wn-clear_drc_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/abell2744clu-grizli-v6.0-f150wn-clear_drc_wht.fits.gz>`_,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/abell2744clu-grizli-v6.0-f200wn-clear_drc_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/abell2744clu-grizli-v6.0-f200wn-clear_drc_wht.fits.gz>`_,abell2744clu
    macs0647,`RGB <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/macs0647-grizli-v6.0.field.jpg>`_ `f444w <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/macs0647-grizli-v6.0.f444w.jpg>`_,GO-1433, , ,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/macs0647-grizli-v6.0-f115w-clear_drc_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/macs0647-grizli-v6.0-f115w-clear_drc_wht.fits.gz>`_,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/macs0647-grizli-v6.0-f150w-clear_drc_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/macs0647-grizli-v6.0-f150w-clear_drc_wht.fits.gz>`_, ,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/macs0647-grizli-v6.0-f200w-clear_drc_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/macs0647-grizli-v6.0-f200w-clear_drc_wht.fits.gz>`_, ,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/macs0647-grizli-v6.0-f277w-clear_drc_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/macs0647-grizli-v6.0-f277w-clear_drc_wht.fits.gz>`_, ,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/macs0647-grizli-v6.0-f356w-clear_drc_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/macs0647-grizli-v6.0-f356w-clear_drc_wht.fits.gz>`_, , ,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/macs0647-grizli-v6.0-f444w-clear_drc_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/macs0647-grizli-v6.0-f444w-clear_drc_wht.fits.gz>`_, ,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/macs0647-grizli-v6.0-f480m-clear_drc_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/macs0647-grizli-v6.0-f480m-clear_drc_wht.fits.gz>`_,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/macs0647-grizli-v6.0-ir_drc_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/macs0647-grizli-v6.0-ir_drc_wht.fits.gz>`_, , , , , , , ,macs0647
    rxj2129,`RGB <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/rxj2129-grizli-v6.0.field.jpg>`_ `f444w <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/rxj2129-grizli-v6.0.f444w.jpg>`_,DD-2767, , ,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/rxj2129-grizli-v6.0-f115w-clear_drc_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/rxj2129-grizli-v6.0-f115w-clear_drc_wht.fits.gz>`_,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/rxj2129-grizli-v6.0-f150w-clear_drc_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/rxj2129-grizli-v6.0-f150w-clear_drc_wht.fits.gz>`_, ,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/rxj2129-grizli-v6.0-f200w-clear_drc_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/rxj2129-grizli-v6.0-f200w-clear_drc_wht.fits.gz>`_, ,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/rxj2129-grizli-v6.0-f277w-clear_drc_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/rxj2129-grizli-v6.0-f277w-clear_drc_wht.fits.gz>`_, ,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/rxj2129-grizli-v6.0-f356w-clear_drc_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/rxj2129-grizli-v6.0-f356w-clear_drc_wht.fits.gz>`_, , ,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/rxj2129-grizli-v6.0-f444w-clear_drc_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/rxj2129-grizli-v6.0-f444w-clear_drc_wht.fits.gz>`_, , ,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/rxj2129-grizli-v6.0-ir_drc_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/rxj2129-grizli-v6.0-ir_drc_wht.fits.gz>`_, , , , , , , ,rxj2129
    sgas1723,`RGB <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/sgas1723-grizli-v6.0.field.jpg>`_ `f444w <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/sgas1723-grizli-v6.0.f444w.jpg>`_,ERS-1355, , ,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/sgas1723-grizli-v6.0-f115w-clear_drc_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/sgas1723-grizli-v6.0-f115w-clear_drc_wht.fits.gz>`_,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/sgas1723-grizli-v6.0-f150w-clear_drc_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/sgas1723-grizli-v6.0-f150w-clear_drc_wht.fits.gz>`_, ,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/sgas1723-grizli-v6.0-f200w-clear_drc_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/sgas1723-grizli-v6.0-f200w-clear_drc_wht.fits.gz>`_, ,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/sgas1723-grizli-v6.0-f277w-clear_drc_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/sgas1723-grizli-v6.0-f277w-clear_drc_wht.fits.gz>`_, ,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/sgas1723-grizli-v6.0-f356w-clear_drc_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/sgas1723-grizli-v6.0-f356w-clear_drc_wht.fits.gz>`_, , ,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/sgas1723-grizli-v6.0-f444w-clear_drc_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/sgas1723-grizli-v6.0-f444w-clear_drc_wht.fits.gz>`_, , , , , , , , , , ,sgas1723
    smacs0723,`RGB <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/smacs0723-grizli-v6.0.field.jpg>`_ `f444w <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/smacs0723-grizli-v6.0.f444w.jpg>`_,ERO-2736, ,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/smacs0723-grizli-v6.0-f090w-clear_drc_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/smacs0723-grizli-v6.0-f090w-clear_drc_wht.fits.gz>`_, ,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/smacs0723-grizli-v6.0-f150w-clear_drc_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/smacs0723-grizli-v6.0-f150w-clear_drc_wht.fits.gz>`_, ,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/smacs0723-grizli-v6.0-f200w-clear_drc_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/smacs0723-grizli-v6.0-f200w-clear_drc_wht.fits.gz>`_, ,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/smacs0723-grizli-v6.0-f277w-clear_drc_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/smacs0723-grizli-v6.0-f277w-clear_drc_wht.fits.gz>`_, ,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/smacs0723-grizli-v6.0-f356w-clear_drc_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/smacs0723-grizli-v6.0-f356w-clear_drc_wht.fits.gz>`_, , ,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/smacs0723-grizli-v6.0-f444w-clear_drc_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/smacs0723-grizli-v6.0-f444w-clear_drc_wht.fits.gz>`_, , ,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/smacs0723-grizli-v6.0-ir_drc_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/smacs0723-grizli-v6.0-ir_drc_wht.fits.gz>`_, , , , ,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/smacs0723-grizli-v6.0-f115wn-clear_drc_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/smacs0723-grizli-v6.0-f115wn-clear_drc_wht.fits.gz>`_, ,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/smacs0723-grizli-v6.0-f200wn-clear_drc_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/smacs0723-grizli-v6.0-f200wn-clear_drc_wht.fits.gz>`_,smacs0723
    sunrise,`RGB <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/sunrise-grizli-v6.0.field.jpg>`_ `f444w <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/sunrise-grizli-v6.0.f444w.jpg>`_,GO-2282, ,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/sunrise-grizli-v6.0-f090w-clear_drc_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/sunrise-grizli-v6.0-f090w-clear_drc_wht.fits.gz>`_,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/sunrise-grizli-v6.0-f115w-clear_drc_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/sunrise-grizli-v6.0-f115w-clear_drc_wht.fits.gz>`_,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/sunrise-grizli-v6.0-f150w-clear_drc_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/sunrise-grizli-v6.0-f150w-clear_drc_wht.fits.gz>`_, ,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/sunrise-grizli-v6.0-f200w-clear_drc_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/sunrise-grizli-v6.0-f200w-clear_drc_wht.fits.gz>`_, ,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/sunrise-grizli-v6.0-f277w-clear_drc_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/sunrise-grizli-v6.0-f277w-clear_drc_wht.fits.gz>`_, ,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/sunrise-grizli-v6.0-f356w-clear_drc_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/sunrise-grizli-v6.0-f356w-clear_drc_wht.fits.gz>`_,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/sunrise-grizli-v6.0-f410m-clear_drc_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/sunrise-grizli-v6.0-f410m-clear_drc_wht.fits.gz>`_, ,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/sunrise-grizli-v6.0-f444w-clear_drc_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/sunrise-grizli-v6.0-f444w-clear_drc_wht.fits.gz>`_, , ,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/sunrise-grizli-v6.0-ir_drc_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/sunrise-grizli-v6.0-ir_drc_wht.fits.gz>`_, , , , , , , ,sunrise

HST Imaging Data
~~~~~~~~~~~~~~~~

* All mosaics drizzled to the same 40mas pixel grid as the JWST LW images above
* Some HST fields have earlier version numbers, generally when the pixel grids have not changed since previous runs of the mosaic creation


.. csv-table ::

    field,IMG,note,f105w,f110w,f125w,f140w,f160w,f225wu,f275wu,f336wu,f350lpu,f390wu,f435w,f475w,f555w,f606w,f606wu,f625w,f775w,f814w,f814wu,f850lp,f850lpu,_field
    ceers-full,`RGB <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/ceers-full-grizli-v6.0.field.jpg>`_ `f444w <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/ceers-full-grizli-v6.0.f444w.jpg>`_,ERS-1345,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v5/ceers-full/ceers-full-grizli-v5.0-f105w_drz_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v5/ceers-full/ceers-full-grizli-v5.0-f105w_drz_wht.fits.gz>`_, ,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v5/ceers-full/ceers-full-grizli-v5.0-f125w_drz_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v5/ceers-full/ceers-full-grizli-v5.0-f125w_drz_wht.fits.gz>`_,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v5/ceers-full/ceers-full-grizli-v5.0-f140w_drz_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v5/ceers-full/ceers-full-grizli-v5.0-f140w_drz_wht.fits.gz>`_,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v5/ceers-full/ceers-full-grizli-v5.0-f160w_drz_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v5/ceers-full/ceers-full-grizli-v5.0-f160w_drz_wht.fits.gz>`_, ,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v5/ceers-full/ceers-full-grizli-v5.0-f275wu_drc_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v5/ceers-full/ceers-full-grizli-v5.0-f275wu_drc_wht.fits.gz>`_, , , ,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v5/ceers-full/ceers-full-grizli-v5.0-f435w_drc_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v5/ceers-full/ceers-full-grizli-v5.0-f435w_drc_wht.fits.gz>`_, , ,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v5/ceers-full/ceers-full-grizli-v5.0-f606w_drc_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v5/ceers-full/ceers-full-grizli-v5.0-f606w_drc_wht.fits.gz>`_,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v5/ceers-full/ceers-full-grizli-v5.0-f606wu_drc_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v5/ceers-full/ceers-full-grizli-v5.0-f606wu_drc_wht.fits.gz>`_, , ,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v5/ceers-full/ceers-full-grizli-v5.0-f814w_drc_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v5/ceers-full/ceers-full-grizli-v5.0-f814w_drc_wht.fits.gz>`_, , , ,ceers-full
    cosweb,`RGB <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/cosweb-grizli-v6.0.field.jpg>`_ `f444w <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/cosweb-grizli-v6.0.f444w.jpg>`_,First epoch,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/cosweb-grizli-v6.0-f105w_drz_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/cosweb-grizli-v6.0-f105w_drz_wht.fits.gz>`_,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/cosweb-grizli-v6.0-f110w_drz_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/cosweb-grizli-v6.0-f110w_drz_wht.fits.gz>`_,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/cosweb-grizli-v6.0-f125w_drz_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/cosweb-grizli-v6.0-f125w_drz_wht.fits.gz>`_,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/cosweb-grizli-v6.0-f140w_drz_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/cosweb-grizli-v6.0-f140w_drz_wht.fits.gz>`_,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/cosweb-grizli-v6.0-f160w_drz_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/cosweb-grizli-v6.0-f160w_drz_wht.fits.gz>`_, , , ,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/cosweb-grizli-v6.0-f350lpu_drc_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/cosweb-grizli-v6.0-f350lpu_drc_wht.fits.gz>`_, ,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/cosweb-grizli-v6.0-f435w_drc_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/cosweb-grizli-v6.0-f435w_drc_wht.fits.gz>`_,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/cosweb-grizli-v6.0-f475w_drc_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/cosweb-grizli-v6.0-f475w_drc_wht.fits.gz>`_, ,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/cosweb-grizli-v6.0-f606w_drc_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/cosweb-grizli-v6.0-f606w_drc_wht.fits.gz>`_, , , ,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/cosweb-grizli-v6.0-f814w_drc_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/cosweb-grizli-v6.0-f814w_drc_wht.fits.gz>`_, ,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/cosweb-grizli-v6.0-f850lp_drc_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/cosweb-grizli-v6.0-f850lp_drc_wht.fits.gz>`_, ,cosweb
    primer-cosmos,`RGB <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/primer-cosmos-grizli-v6.0.field.jpg>`_ `f444w <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/primer-cosmos-grizli-v6.0.f444w.jpg>`_,GO-1837,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/primer-cosmos-grizli-v6.0-f105w_drz_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/primer-cosmos-grizli-v6.0-f105w_drz_wht.fits.gz>`_,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/primer-cosmos-grizli-v6.0-f110w_drz_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/primer-cosmos-grizli-v6.0-f110w_drz_wht.fits.gz>`_,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/primer-cosmos-grizli-v6.0-f125w_drz_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/primer-cosmos-grizli-v6.0-f125w_drz_wht.fits.gz>`_,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/primer-cosmos-grizli-v6.0-f140w_drz_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/primer-cosmos-grizli-v6.0-f140w_drz_wht.fits.gz>`_,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/primer-cosmos-grizli-v6.0-f160w_drz_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/primer-cosmos-grizli-v6.0-f160w_drz_wht.fits.gz>`_, ,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/primer-cosmos-grizli-v6.0-f275wu_drc_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/primer-cosmos-grizli-v6.0-f275wu_drc_wht.fits.gz>`_,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/primer-cosmos-grizli-v6.0-f336wu_drc_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/primer-cosmos-grizli-v6.0-f336wu_drc_wht.fits.gz>`_,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/primer-cosmos-grizli-v6.0-f350lpu_drc_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/primer-cosmos-grizli-v6.0-f350lpu_drc_wht.fits.gz>`_, ,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/primer-cosmos-grizli-v6.0-f435w_drc_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/primer-cosmos-grizli-v6.0-f435w_drc_wht.fits.gz>`_,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/primer-cosmos-grizli-v6.0-f475w_drc_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/primer-cosmos-grizli-v6.0-f475w_drc_wht.fits.gz>`_, ,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/primer-cosmos-grizli-v6.0-f606w_drc_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/primer-cosmos-grizli-v6.0-f606w_drc_wht.fits.gz>`_,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/primer-cosmos-grizli-v6.0-f606wu_drc_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/primer-cosmos-grizli-v6.0-f606wu_drc_wht.fits.gz>`_, , ,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/primer-cosmos-grizli-v6.0-f814w_drc_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/primer-cosmos-grizli-v6.0-f814w_drc_wht.fits.gz>`_, ,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/primer-cosmos-grizli-v6.0-f850lp_drc_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/primer-cosmos-grizli-v6.0-f850lp_drc_wht.fits.gz>`_, ,primer-cosmos
    primer-uds,`RGB <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/primer-uds-grizli-v6.0.field.jpg>`_ `f444w <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/primer-uds-grizli-v6.0.f444w.jpg>`_,GO-1837,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/primer-uds-grizli-v6.0-f105w_drz_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/primer-uds-grizli-v6.0-f105w_drz_wht.fits.gz>`_, ,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/primer-uds-grizli-v6.0-f125w_drz_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/primer-uds-grizli-v6.0-f125w_drz_wht.fits.gz>`_,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/primer-uds-grizli-v6.0-f140w_drz_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/primer-uds-grizli-v6.0-f140w_drz_wht.fits.gz>`_,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/primer-uds-grizli-v6.0-f160w_drz_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/primer-uds-grizli-v6.0-f160w_drz_wht.fits.gz>`_, , , ,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/primer-uds-grizli-v6.0-f350lpu_drc_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/primer-uds-grizli-v6.0-f350lpu_drc_wht.fits.gz>`_, ,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/primer-uds-grizli-v6.0-f435w_drc_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/primer-uds-grizli-v6.0-f435w_drc_wht.fits.gz>`_, , ,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/primer-uds-grizli-v6.0-f606w_drc_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/primer-uds-grizli-v6.0-f606w_drc_wht.fits.gz>`_, , ,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/primer-uds-grizli-v6.0-f775w_drc_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/primer-uds-grizli-v6.0-f775w_drc_wht.fits.gz>`_,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/primer-uds-grizli-v6.0-f814w_drc_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/primer-uds-grizli-v6.0-f814w_drc_wht.fits.gz>`_, ,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/primer-uds-grizli-v6.0-f850lp_drc_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/primer-uds-grizli-v6.0-f850lp_drc_wht.fits.gz>`_, ,primer-uds
    gdn,`RGB <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/gdn-grizli-v6.0.field.jpg>`_ `f444w <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/gdn-grizli-v6.0.f444w.jpg>`_,FRESCO,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v5/fresco-gdn/gdn-grizli-v5.1-f105w_drz_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v5/fresco-gdn/gdn-grizli-v5.1-f105w_drz_wht.fits.gz>`_,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v5/fresco-gdn/gdn-grizli-v5.1-f110w_drz_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v5/fresco-gdn/gdn-grizli-v5.1-f110w_drz_wht.fits.gz>`_,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v5/fresco-gdn/gdn-grizli-v5.1-f125w_drz_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v5/fresco-gdn/gdn-grizli-v5.1-f125w_drz_wht.fits.gz>`_,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v5/fresco-gdn/gdn-grizli-v5.1-f140w_drz_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v5/fresco-gdn/gdn-grizli-v5.1-f140w_drz_wht.fits.gz>`_,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v5/fresco-gdn/gdn-grizli-v5.1-f160w_drz_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v5/fresco-gdn/gdn-grizli-v5.1-f160w_drz_wht.fits.gz>`_, ,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v5/fresco-gdn/gdn-grizli-v5.1-f275wu_drc_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v5/fresco-gdn/gdn-grizli-v5.1-f275wu_drc_wht.fits.gz>`_,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v5/fresco-gdn/gdn-grizli-v5.1-f336wu_drc_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v5/fresco-gdn/gdn-grizli-v5.1-f336wu_drc_wht.fits.gz>`_,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v5/fresco-gdn/gdn-grizli-v5.1-f350lpu_drc_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v5/fresco-gdn/gdn-grizli-v5.1-f350lpu_drc_wht.fits.gz>`_, ,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v5/fresco-gdn/gdn-grizli-v5.1-f435w_drc_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v5/fresco-gdn/gdn-grizli-v5.1-f435w_drc_wht.fits.gz>`_, , ,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v5/fresco-gdn/gdn-grizli-v5.1-f606w_drc_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v5/fresco-gdn/gdn-grizli-v5.1-f606w_drc_wht.fits.gz>`_, , ,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v5/fresco-gdn/gdn-grizli-v5.1-f775w_drc_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v5/fresco-gdn/gdn-grizli-v5.1-f775w_drc_wht.fits.gz>`_,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v5/fresco-gdn/gdn-grizli-v5.1-f814w_drc_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v5/fresco-gdn/gdn-grizli-v5.1-f814w_drc_wht.fits.gz>`_, ,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v5/fresco-gdn/gdn-grizli-v5.1-f850lp_drc_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v5/fresco-gdn/gdn-grizli-v5.1-f850lp_drc_wht.fits.gz>`_,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v5/fresco-gdn/gdn-grizli-v5.1-f850lpu_drc_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v5/fresco-gdn/gdn-grizli-v5.1-f850lpu_drc_wht.fits.gz>`_,gdn
    gds,`RGB <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/gds-grizli-v6.0.field.jpg>`_ `f444w <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/gds-grizli-v6.0.f444w.jpg>`_,"FRESCO, GO-1963",`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v5/fresco/gds-grizli-v5.0-f105w_drz_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v5/fresco/gds-grizli-v5.0-f105w_drz_wht.fits.gz>`_,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v5/fresco/gds-grizli-v5.0-f110w_drz_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v5/fresco/gds-grizli-v5.0-f110w_drz_wht.fits.gz>`_,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v5/fresco/gds-grizli-v5.0-f125w_drz_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v5/fresco/gds-grizli-v5.0-f125w_drz_wht.fits.gz>`_,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v5/fresco/gds-grizli-v5.0-f140w_drz_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v5/fresco/gds-grizli-v5.0-f140w_drz_wht.fits.gz>`_,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v5/fresco/gds-grizli-v5.0-f160w_drz_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v5/fresco/gds-grizli-v5.0-f160w_drz_wht.fits.gz>`_, , ,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v5/fresco/gds-grizli-v5.0-f336wu_drc_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v5/fresco/gds-grizli-v5.0-f336wu_drc_wht.fits.gz>`_, , ,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v5/fresco/gds-grizli-v5.0-f435w_drc_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v5/fresco/gds-grizli-v5.0-f435w_drc_wht.fits.gz>`_,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v5/fresco/gds-grizli-v5.0-f475w_drc_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v5/fresco/gds-grizli-v5.0-f475w_drc_wht.fits.gz>`_, ,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v5/fresco/gds-grizli-v5.0-f606w_drc_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v5/fresco/gds-grizli-v5.0-f606w_drc_wht.fits.gz>`_,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v5/fresco/gds-grizli-v5.0-f606wu_drc_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v5/fresco/gds-grizli-v5.0-f606wu_drc_wht.fits.gz>`_, ,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v5/fresco/gds-grizli-v5.0-f775w_drc_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v5/fresco/gds-grizli-v5.0-f775w_drc_wht.fits.gz>`_,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v5/fresco/gds-grizli-v5.0-f814w_drc_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v5/fresco/gds-grizli-v5.0-f814w_drc_wht.fits.gz>`_,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v5/fresco/gds-grizli-v5.0-f814wu_drc_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v5/fresco/gds-grizli-v5.0-f814wu_drc_wht.fits.gz>`_,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v5/fresco/gds-grizli-v5.0-f850lp_drc_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v5/fresco/gds-grizli-v5.0-f850lp_drc_wht.fits.gz>`_,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v5/fresco/gds-grizli-v5.0-f850lpu_drc_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v5/fresco/gds-grizli-v5.0-f850lpu_drc_wht.fits.gz>`_,gds
    ngdeep,`RGB <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/ngdeep-grizli-v6.0.field.jpg>`_ `f444w <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/ngdeep-grizli-v6.0.f444w.jpg>`_,GO-2079,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v5/ngdeep/ngdeep-grizli-v5.0-f105w_drz_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v5/ngdeep/ngdeep-grizli-v5.0-f105w_drz_wht.fits.gz>`_, ,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v5/ngdeep/ngdeep-grizli-v5.0-f125w_drz_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v5/ngdeep/ngdeep-grizli-v5.0-f125w_drz_wht.fits.gz>`_,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v5/ngdeep/ngdeep-grizli-v5.0-f140w_drz_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v5/ngdeep/ngdeep-grizli-v5.0-f140w_drz_wht.fits.gz>`_,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v5/ngdeep/ngdeep-grizli-v5.0-f160w_drz_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v5/ngdeep/ngdeep-grizli-v5.0-f160w_drz_wht.fits.gz>`_, , ,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v5/ngdeep/ngdeep-grizli-v5.0-f336wu_drc_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v5/ngdeep/ngdeep-grizli-v5.0-f336wu_drc_wht.fits.gz>`_,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v5/ngdeep/ngdeep-grizli-v5.0-f350lpu_drc_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v5/ngdeep/ngdeep-grizli-v5.0-f350lpu_drc_wht.fits.gz>`_, ,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v5/ngdeep/ngdeep-grizli-v5.0-f435w_drc_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v5/ngdeep/ngdeep-grizli-v5.0-f435w_drc_wht.fits.gz>`_,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v5/ngdeep/ngdeep-grizli-v5.0-f475w_drc_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v5/ngdeep/ngdeep-grizli-v5.0-f475w_drc_wht.fits.gz>`_, ,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v5/ngdeep/ngdeep-grizli-v5.0-f606w_drc_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v5/ngdeep/ngdeep-grizli-v5.0-f606w_drc_wht.fits.gz>`_, , ,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v5/ngdeep/ngdeep-grizli-v5.0-f775w_drc_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v5/ngdeep/ngdeep-grizli-v5.0-f775w_drc_wht.fits.gz>`_,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v5/ngdeep/ngdeep-grizli-v5.0-f814w_drc_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v5/ngdeep/ngdeep-grizli-v5.0-f814w_drc_wht.fits.gz>`_, ,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v5/ngdeep/ngdeep-grizli-v5.0-f850lp_drc_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v5/ngdeep/ngdeep-grizli-v5.0-f850lp_drc_wht.fits.gz>`_, ,ngdeep
    j1235,`RGB <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/j1235-grizli-v6.0.field.jpg>`_ `f444w <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/j1235-grizli-v6.0.f444w.jpg>`_,COM-1063, , , , , , , , , , , , , , , , , , , , , ,j1235
    jwst-nep-tdf-nrc,`RGB <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/jwst-nep-tdf-nrc-grizli-v6.0.field.jpg>`_ `f444w <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/jwst-nep-tdf-nrc-grizli-v6.0.f444w.jpg>`_,GTO-2738, , , , , , , , , , ,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v4/jwst-nep-tdf-nrc-grizli-v4.0-f435w_drc_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v4/jwst-nep-tdf-nrc-grizli-v4.0-f435w_drc_wht.fits.gz>`_, , ,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v4/jwst-nep-tdf-nrc-grizli-v4.0-f606w_drc_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v4/jwst-nep-tdf-nrc-grizli-v4.0-f606w_drc_wht.fits.gz>`_, , , , , , , ,jwst-nep-tdf-nrc
    abell2744clu,`RGB <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/abell2744clu-grizli-v6.0.field.jpg>`_ `f444w <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/abell2744clu-grizli-v6.0.f444w.jpg>`_,"GLASS-ERS, UNCOVER, DD-2756",`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v5/uncover/full/abell2744clu-grizli-v5.4-f105w_drz_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v5/uncover/full/abell2744clu-grizli-v5.4-f105w_drz_wht.fits.gz>`_, ,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v5/uncover/full/abell2744clu-grizli-v5.4-f125w_drz_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v5/uncover/full/abell2744clu-grizli-v5.4-f125w_drz_wht.fits.gz>`_,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v5/uncover/full/abell2744clu-grizli-v5.4-f140w_drz_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v5/uncover/full/abell2744clu-grizli-v5.4-f140w_drz_wht.fits.gz>`_,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v5/uncover/full/abell2744clu-grizli-v5.4-f160w_drz_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v5/uncover/full/abell2744clu-grizli-v5.4-f160w_drz_wht.fits.gz>`_,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v5/uncover/full/abell2744clu-grizli-v5.4-f225wu_drc_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v5/uncover/full/abell2744clu-grizli-v5.4-f225wu_drc_wht.fits.gz>`_,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v5/uncover/full/abell2744clu-grizli-v5.4-f275wu_drc_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v5/uncover/full/abell2744clu-grizli-v5.4-f275wu_drc_wht.fits.gz>`_,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v5/uncover/full/abell2744clu-grizli-v5.4-f336wu_drc_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v5/uncover/full/abell2744clu-grizli-v5.4-f336wu_drc_wht.fits.gz>`_, , ,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v5/uncover/full/abell2744clu-grizli-v5.4-f435w_drc_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v5/uncover/full/abell2744clu-grizli-v5.4-f435w_drc_wht.fits.gz>`_,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v5/uncover/full/abell2744clu-grizli-v5.4-f475w_drc_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v5/uncover/full/abell2744clu-grizli-v5.4-f475w_drc_wht.fits.gz>`_, ,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v5/uncover/full/abell2744clu-grizli-v5.4-f606w_drc_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v5/uncover/full/abell2744clu-grizli-v5.4-f606w_drc_wht.fits.gz>`_, , ,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v5/uncover/full/abell2744clu-grizli-v5.4-f775w_drc_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v5/uncover/full/abell2744clu-grizli-v5.4-f775w_drc_wht.fits.gz>`_,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v5/uncover/full/abell2744clu-grizli-v5.4-f814w_drc_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v5/uncover/full/abell2744clu-grizli-v5.4-f814w_drc_wht.fits.gz>`_, , , ,abell2744clu
    macs0647,`RGB <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/macs0647-grizli-v6.0.field.jpg>`_ `f444w <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/macs0647-grizli-v6.0.f444w.jpg>`_,GO-1433,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/macs0647-grizli-v6.0-f105w_drz_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/macs0647-grizli-v6.0-f105w_drz_wht.fits.gz>`_,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/macs0647-grizli-v6.0-f110w_drz_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/macs0647-grizli-v6.0-f110w_drz_wht.fits.gz>`_,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/macs0647-grizli-v6.0-f125w_drz_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/macs0647-grizli-v6.0-f125w_drz_wht.fits.gz>`_,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/macs0647-grizli-v6.0-f140w_drz_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/macs0647-grizli-v6.0-f140w_drz_wht.fits.gz>`_,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/macs0647-grizli-v6.0-f160w_drz_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/macs0647-grizli-v6.0-f160w_drz_wht.fits.gz>`_, ,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/macs0647-grizli-v6.0-f275wu_drc_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/macs0647-grizli-v6.0-f275wu_drc_wht.fits.gz>`_,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/macs0647-grizli-v6.0-f336wu_drc_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/macs0647-grizli-v6.0-f336wu_drc_wht.fits.gz>`_,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/macs0647-grizli-v6.0-f350lpu_drc_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/macs0647-grizli-v6.0-f350lpu_drc_wht.fits.gz>`_,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/macs0647-grizli-v6.0-f390wu_drc_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/macs0647-grizli-v6.0-f390wu_drc_wht.fits.gz>`_,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/macs0647-grizli-v6.0-f435w_drc_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/macs0647-grizli-v6.0-f435w_drc_wht.fits.gz>`_,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/macs0647-grizli-v6.0-f475w_drc_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/macs0647-grizli-v6.0-f475w_drc_wht.fits.gz>`_,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/macs0647-grizli-v6.0-f555w_drc_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/macs0647-grizli-v6.0-f555w_drc_wht.fits.gz>`_,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/macs0647-grizli-v6.0-f606w_drc_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/macs0647-grizli-v6.0-f606w_drc_wht.fits.gz>`_, ,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/macs0647-grizli-v6.0-f625w_drc_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/macs0647-grizli-v6.0-f625w_drc_wht.fits.gz>`_,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/macs0647-grizli-v6.0-f775w_drc_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/macs0647-grizli-v6.0-f775w_drc_wht.fits.gz>`_,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/macs0647-grizli-v6.0-f814w_drc_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/macs0647-grizli-v6.0-f814w_drc_wht.fits.gz>`_, ,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/macs0647-grizli-v6.0-f850lp_drc_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/macs0647-grizli-v6.0-f850lp_drc_wht.fits.gz>`_, ,macs0647
    rxj2129,`RGB <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/rxj2129-grizli-v6.0.field.jpg>`_ `f444w <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/rxj2129-grizli-v6.0.f444w.jpg>`_,DD-2767,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/rxj2129-grizli-v6.0-f105w_drz_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/rxj2129-grizli-v6.0-f105w_drz_wht.fits.gz>`_,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/rxj2129-grizli-v6.0-f110w_drz_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/rxj2129-grizli-v6.0-f110w_drz_wht.fits.gz>`_,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/rxj2129-grizli-v6.0-f125w_drz_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/rxj2129-grizli-v6.0-f125w_drz_wht.fits.gz>`_,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/rxj2129-grizli-v6.0-f140w_drz_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/rxj2129-grizli-v6.0-f140w_drz_wht.fits.gz>`_,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/rxj2129-grizli-v6.0-f160w_drz_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/rxj2129-grizli-v6.0-f160w_drz_wht.fits.gz>`_,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/rxj2129-grizli-v6.0-f225wu_drc_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/rxj2129-grizli-v6.0-f225wu_drc_wht.fits.gz>`_, ,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/rxj2129-grizli-v6.0-f336wu_drc_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/rxj2129-grizli-v6.0-f336wu_drc_wht.fits.gz>`_, ,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/rxj2129-grizli-v6.0-f390wu_drc_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/rxj2129-grizli-v6.0-f390wu_drc_wht.fits.gz>`_,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/rxj2129-grizli-v6.0-f435w_drc_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/rxj2129-grizli-v6.0-f435w_drc_wht.fits.gz>`_,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/rxj2129-grizli-v6.0-f475w_drc_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/rxj2129-grizli-v6.0-f475w_drc_wht.fits.gz>`_,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/rxj2129-grizli-v6.0-f555w_drc_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/rxj2129-grizli-v6.0-f555w_drc_wht.fits.gz>`_,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/rxj2129-grizli-v6.0-f606w_drc_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/rxj2129-grizli-v6.0-f606w_drc_wht.fits.gz>`_,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/rxj2129-grizli-v6.0-f606wu_drc_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/rxj2129-grizli-v6.0-f606wu_drc_wht.fits.gz>`_,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/rxj2129-grizli-v6.0-f625w_drc_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/rxj2129-grizli-v6.0-f625w_drc_wht.fits.gz>`_,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/rxj2129-grizli-v6.0-f775w_drc_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/rxj2129-grizli-v6.0-f775w_drc_wht.fits.gz>`_,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/rxj2129-grizli-v6.0-f814w_drc_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/rxj2129-grizli-v6.0-f814w_drc_wht.fits.gz>`_, ,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/rxj2129-grizli-v6.0-f850lp_drc_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/rxj2129-grizli-v6.0-f850lp_drc_wht.fits.gz>`_, ,rxj2129
    sgas1723,`RGB <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/sgas1723-grizli-v6.0.field.jpg>`_ `f444w <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/sgas1723-grizli-v6.0.f444w.jpg>`_,ERS-1355, , , , , , , , , , , , , , , , , , , , , ,sgas1723
    smacs0723,`RGB <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/smacs0723-grizli-v6.0.field.jpg>`_ `f444w <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/smacs0723-grizli-v6.0.f444w.jpg>`_,ERO-2736,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v4/smacs0723-grizli-v4.0-f105w_drz_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v4/smacs0723-grizli-v4.0-f105w_drz_wht.fits.gz>`_, ,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v4/smacs0723-grizli-v4.0-f125w_drz_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v4/smacs0723-grizli-v4.0-f125w_drz_wht.fits.gz>`_,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v4/smacs0723-grizli-v4.0-f140w_drz_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v4/smacs0723-grizli-v4.0-f140w_drz_wht.fits.gz>`_,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v4/smacs0723-grizli-v4.0-f160w_drz_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v4/smacs0723-grizli-v4.0-f160w_drz_wht.fits.gz>`_, , , , , ,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v4/smacs0723-grizli-v4.0-f435w_drc_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v4/smacs0723-grizli-v4.0-f435w_drc_wht.fits.gz>`_, , ,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v4/smacs0723-grizli-v4.0-f606w_drc_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v4/smacs0723-grizli-v4.0-f606w_drc_wht.fits.gz>`_, , , ,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v4/smacs0723-grizli-v4.0-f814w_drc_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v4/smacs0723-grizli-v4.0-f814w_drc_wht.fits.gz>`_, , , ,smacs0723
    sunrise,`RGB <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/sunrise-grizli-v6.0.field.jpg>`_ `f444w <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/sunrise-grizli-v6.0.f444w.jpg>`_,GO-2282,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/sunrise-grizli-v6.0-f105w_drz_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/sunrise-grizli-v6.0-f105w_drz_wht.fits.gz>`_,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/sunrise-grizli-v6.0-f110w_drz_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/sunrise-grizli-v6.0-f110w_drz_wht.fits.gz>`_,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/sunrise-grizli-v6.0-f125w_drz_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/sunrise-grizli-v6.0-f125w_drz_wht.fits.gz>`_,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/sunrise-grizli-v6.0-f140w_drz_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/sunrise-grizli-v6.0-f140w_drz_wht.fits.gz>`_,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/sunrise-grizli-v6.0-f160w_drz_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/sunrise-grizli-v6.0-f160w_drz_wht.fits.gz>`_, , , , , ,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/sunrise-grizli-v6.0-f435w_drc_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/sunrise-grizli-v6.0-f435w_drc_wht.fits.gz>`_,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/sunrise-grizli-v6.0-f475w_drc_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/sunrise-grizli-v6.0-f475w_drc_wht.fits.gz>`_, ,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/sunrise-grizli-v6.0-f606w_drc_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/sunrise-grizli-v6.0-f606w_drc_wht.fits.gz>`_, , , ,`S <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/sunrise-grizli-v6.0-f814w_drc_sci.fits.gz>`_ `W <https://s3.amazonaws.com/grizli-v2/JwstMosaics/v6/sunrise-grizli-v6.0-f814w_drc_wht.fits.gz>`_, , , ,sunrise
